# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitionOrganiserInfo(BaseModel):
    get_competition_organiser_info: Optional[
        "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo"
    ] = Field(alias="getCompetitionOrganiserInfo")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo(BaseModel):
    units: Optional[
        List[Optional["GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits"]]
    ]
    prize_money: Optional[
        List[
            Optional["GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoPrizeMoney"]
        ]
    ] = Field(alias="prizeMoney")
    website_url: Optional[str] = Field(alias="websiteUrl")
    results_page_url: Optional[str] = Field(alias="resultsPageUrl")
    live_streaming_url: Optional[str] = Field(alias="liveStreamingUrl")
    additional_info: Optional[str] = Field(alias="additionalInfo")
    contact_persons: Optional[
        List[
            Optional[
                "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersons"
            ]
        ]
    ] = Field(alias="contactPersons")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits(BaseModel):
    events: Optional[List[Optional[str]]]
    gender: Optional[str]


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoPrizeMoney(BaseModel):
    gender: Optional[str]
    prizes: Optional[List[Optional[str]]]


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersons(BaseModel):
    name: Optional[str]
    email: Optional[str]
    phone_number: Optional[str] = Field(alias="phoneNumber")
    title: Optional[str]


GetCompetitionOrganiserInfo.model_rebuild()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRecordsDisciplineList(BaseModel):
    get_records_discipline_list: Optional[
        List[Optional["GetRecordsDisciplineListGetRecordsDisciplineList"]]
    ] = Field(alias="getRecordsDisciplineList")


class GetRecordsDisciplineListGetRecordsDisciplineList(BaseModel):
    gender: Optional[str]
    discipline_types: Optional[
        List[
            Optional["GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypes"]
        ]
    ] = Field(alias="disciplineTypes")


class GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypes(BaseModel):
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    disciplines: Optional[
        List[
            Optional[
                "GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypesDisciplines"
            ]
        ]
    ]


class GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypesDisciplines(
    BaseModel
):
    event_id: Optional[str] = Field(alias="eventId")
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")


GetRecordsDisciplineList.model_rebuild()
GetRecordsDisciplineListGetRecordsDisciplineList.model_rebuild()
GetRecordsDisciplineListGetRecordsDisciplineListDisciplineTypes.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetPredictorGameBanner(BaseModel):
    get_predictor_game_banner: Optional[
        "GetPredictorGameBannerGetPredictorGameBanner"
    ] = Field(alias="getPredictorGameBanner")


class GetPredictorGameBannerGetPredictorGameBanner(BaseModel):
    id: Optional[int]
    desktop_banner_id: Optional[str] = Field(alias="desktopBannerId")
    desktop_banner_edited: Optional[str] = Field(alias="desktopBannerEdited")
    mobile_banner_id: Optional[str] = Field(alias="mobileBannerId")
    mobile_banner_edited: Optional[str] = Field(alias="mobileBannerEdited")
    banner_url: Optional[str] = Field(alias="bannerUrl")
    is_live: Optional[bool] = Field(alias="isLive")


GetPredictorGameBanner.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSchedule(BaseModel):
    get_schedule: Optional["GetScheduleGetSchedule"] = Field(alias="getSchedule")


class GetScheduleGetSchedule(BaseModel):
    id: Optional[str]
    country_id: Optional[str] = Field(alias="countryId")
    country_name: Optional[str] = Field(alias="countryName")
    event_id: Optional[str] = Field(alias="eventId")
    event_id_wa: Optional[str] = Field(alias="eventId_WA")
    days: Optional[List[Optional["GetScheduleGetScheduleDays"]]]


class GetScheduleGetScheduleDays(BaseModel):
    day: Optional[int]
    date: Optional[Any]
    channels: Optional[List[Optional["GetScheduleGetScheduleDaysChannels"]]]


class GetScheduleGetScheduleDaysChannels(BaseModel):
    id: Optional[str] = Field(alias="_id")
    category: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_file_name: Optional[str] = Field(alias="logoFileName")
    title: Optional[str]
    time: Optional[List[Optional[str]]]


GetSchedule.model_rebuild()
GetScheduleGetSchedule.model_rebuild()
GetScheduleGetScheduleDays.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLegacyPage(BaseModel):
    get_legacy_page: Optional["GetLegacyPageGetLegacyPage"] = Field(
        alias="getLegacyPage"
    )


class GetLegacyPageGetLegacyPage(BaseModel):
    id: Optional[str]
    url: Optional[str] = Field(alias="Url")
    seo_title: Optional[str] = Field(alias="SEOTitle")
    meta_description: Optional[str] = Field(alias="MetaDescription")
    content: Optional[List[Optional["GetLegacyPageGetLegacyPageContent"]]] = Field(
        alias="Content"
    )
    template: Optional["GetLegacyPageGetLegacyPageTemplate"] = Field(alias="Template")
    status: Optional[int] = Field(alias="Status")
    order: Optional[int] = Field(alias="Order")


class GetLegacyPageGetLegacyPageContent(BaseModel):
    id: Optional[str]
    type: Optional[str]
    text: Optional[str] = Field(alias="Text")
    group_id: Optional[str] = Field(alias="GroupId")
    section_id: Optional[str] = Field(alias="SectionId")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    related_media: Optional[
        List[Optional["GetLegacyPageGetLegacyPageContentRelatedMedia"]]
    ] = Field(alias="relatedMedia")
    document_ids: Optional[List[Optional[str]]] = Field(alias="DocumentIds")
    legacy_document: Optional[
        List[Optional["GetLegacyPageGetLegacyPageContentLegacyDocument"]]
    ] = Field(alias="legacyDocument")


class GetLegacyPageGetLegacyPageContentRelatedMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_eo_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_ml_file_name_360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


class GetLegacyPageGetLegacyPageContentLegacyDocument(BaseModel):
    id: Optional[str]
    title: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    description: Optional[str]
    format: Optional[int]
    order: Optional[int]
    files: Optional[
        List[Optional["GetLegacyPageGetLegacyPageContentLegacyDocumentFiles"]]
    ]


class GetLegacyPageGetLegacyPageContentLegacyDocumentFiles(BaseModel):
    language: Optional[int]
    file_name: Optional[str] = Field(alias="fileName")
    order: Optional[int]
    show: Optional[bool]


class GetLegacyPageGetLegacyPageTemplate(BaseModel):
    id: Optional[str]
    display_name: Optional[str] = Field(alias="DisplayName")
    view_name: Optional[str] = Field(alias="ViewName")
    description: Optional[str] = Field(alias="Description")
    show_sort: Optional[bool] = Field(alias="showSort")
    show_filter: Optional[bool] = Field(alias="showFilter")
    filter_text: Optional[str] = Field(alias="FilterText")


GetLegacyPage.model_rebuild()
GetLegacyPageGetLegacyPage.model_rebuild()
GetLegacyPageGetLegacyPageContent.model_rebuild()
GetLegacyPageGetLegacyPageContentLegacyDocument.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCalendarCompetitionResults(BaseModel):
    get_calendar_competition_results: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResults"
    ] = Field(alias="getCalendarCompetitionResults")


class GetCalendarCompetitionResultsGetCalendarCompetitionResults(BaseModel):
    competition: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition"
    ]
    event_titles: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles"
            ]
        ]
    ] = Field(alias="eventTitles")
    options: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions"
    ]
    parameters: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters"
    ]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition(BaseModel):
    date_range: Optional[str] = Field(alias="dateRange")
    end_date: Optional[str] = Field(alias="endDate")
    name: Optional[str]
    ranking_category: Optional[str] = Field(alias="rankingCategory")
    start_date: Optional[str] = Field(alias="startDate")
    venue: Optional[str]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles(BaseModel):
    event_title: Optional[str] = Field(alias="eventTitle")
    events: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents"
            ]
        ]
    ]
    ranking_category: Optional[str] = Field(alias="rankingCategory")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents(
    BaseModel
):
    event: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    gender: Optional[str]
    is_relay: Optional[bool] = Field(alias="isRelay")
    per_result_wind: Optional[bool] = Field(alias="perResultWind")
    races: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces"
            ]
        ]
    ]
    summary: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary"
            ]
        ]
    ]
    with_wind: Optional[bool] = Field(alias="withWind")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces(
    BaseModel
):
    date: Optional[str]
    day: Optional[int]
    race: Optional[str]
    race_id: Optional[int] = Field(alias="raceId")
    race_number: Optional[int] = Field(alias="raceNumber")
    wind: Optional[str]
    results: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResults"
            ]
        ]
    ]
    start_list: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartList"
            ]
        ]
    ] = Field(alias="startList")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResults(
    BaseModel
):
    id: Optional[str]
    competitor: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsCompetitor"
    ]
    mark: Optional[str]
    nationality: Optional[str]
    place: Optional[str]
    points: Optional[int]
    qualified: Optional[bool]
    records: Optional[str]
    wind: Optional[str]
    remark: Optional[str]
    details: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsDetails"
            ]
        ]
    ]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsCompetitor(
    BaseModel
):
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    id: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    birth_date: Optional[str] = Field(alias="birthDate")
    has_profile: Optional[bool] = Field(alias="hasProfile")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResultsDetails(
    BaseModel
):
    event: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    race_number: Optional[int] = Field(alias="raceNumber")
    mark: Optional[str]
    wind: Optional[str]
    place_in_round: Optional[int] = Field(alias="placeInRound")
    place_in_race: Optional[int] = Field(alias="placeInRace")
    points: Optional[int]
    overall_points: Optional[int] = Field(alias="overallPoints")
    place_in_round_by_points: Optional[int] = Field(alias="placeInRoundByPoints")
    overall_place_by_points: Optional[int] = Field(alias="overallPlaceByPoints")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartList(
    BaseModel
):
    competitor: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartListCompetitor"
    ]
    order: Optional[str]
    pb: Optional[str]
    sb: Optional[str]
    bib: Optional[str]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartListCompetitor(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    id: Optional[str]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary(
    BaseModel
):
    competitor: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitor"
    ]
    mark: Optional[str]
    nationality: Optional[str]
    place_in_race: Optional[str] = Field(alias="placeInRace")
    place_in_round: Optional[str] = Field(alias="placeInRound")
    points: Optional[int]
    race_number: Optional[int] = Field(alias="raceNumber")
    records: Optional[str]
    wind: Optional[str]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitor(
    BaseModel
):
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    id: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    birth_date: Optional[str] = Field(alias="birthDate")
    has_profile: Optional[bool] = Field(alias="hasProfile")
    team_members: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitorTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitorTeamMembers(
    BaseModel
):
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions(BaseModel):
    days: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays"
            ]
        ]
    ]
    events: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents"
            ]
        ]
    ]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays(BaseModel):
    date: Optional[str]
    day: Optional[int]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents(
    BaseModel
):
    gender: Optional[str]
    id: Optional[int]
    name: Optional[str]
    combined: Optional[bool]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters(BaseModel):
    competition_id: Optional[int] = Field(alias="competitionId")
    day: Optional[int]
    event_id: Optional[int] = Field(alias="eventId")


GetCalendarCompetitionResults.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResults.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesResults.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRacesStartList.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummaryCompetitor.model_rebuild()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/schema.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class AAapiQuery(BaseModel):
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    gender: Optional[str] = None
    environment: Optional[str] = None
    age_category: Optional[str] = Field(alias="ageCategory", default=None)
    wind_reading: Optional[str] = Field(alias="windReading", default=None)
    category_id: Optional[int] = Field(alias="categoryId", default=None)
    competition_id: Optional[int] = Field(alias="competitionId", default=None)
    event_group: Optional[str] = Field(alias="eventGroup", default=None)
    best_results_only: Optional[bool] = Field(alias="bestResultsOnly", default=None)
    region: Optional[str] = None
    region_type: Optional[str] = Field(alias="regionType", default=None)
    limit: Optional[int] = None
    season: Optional[int] = None
    page: Optional[int] = None
    max_year_available: Optional[int] = Field(alias="maxYearAvailable", default=None)


class ChunkType(BaseModel):
    size: Optional[int] = None
    chunk_order: Optional[int] = Field(alias="chunkOrder", default=None)
    chunk_id: Optional[str] = Field(alias="chunkId", default=None)


class ClientMetadataInput(BaseModel):
    key: Optional[str] = None
    value: Optional[str] = None


class CompetitorInput(BaseModel):
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId", default=None)
    first_name: Optional[str] = Field(alias="firstName", default=None)
    last_name: Optional[str] = Field(alias="lastName", default=None)
    birth_date: Optional[str] = Field(alias="birthDate", default=None)
    birth_place: Optional[str] = Field(alias="birthPlace", default=None)
    birth_country_code: Optional[str] = Field(alias="birthCountryCode", default=None)
    birth_place_country_name: Optional[str] = Field(
        alias="birthPlaceCountryName", default=None
    )
    team_name: Optional[str] = Field(alias="teamName", default=None)
    country_name: Optional[str] = Field(alias="countryName", default=None)
    country_code: Optional[str] = Field(alias="countryCode", default=None)
    sex_code: Optional[str] = Field(alias="sexCode", default=None)
    sex_name: Optional[str] = Field(alias="sexName", default=None)
    full_bio: Optional[str] = Field(alias="fullBio", default=None)
    butlers_bio: Optional[str] = Field(alias="butlersBio", default=None)


class CompetitorQueryInput(BaseModel):
    competitor_id: int = Field(alias="competitorId")


class EventInput(BaseModel):
    id: str
    timezone: Optional[str] = None
    updated_on: Optional[Any] = Field(alias="updatedOn", default=None)
    hash: Optional[str] = None
    name: Optional[str] = None
    start_date: Optional[Any] = Field(alias="startDate", default=None)
    end_date: Optional[Any] = Field(alias="endDate", default=None)
    venue: Optional[str] = None
    country_code: Optional[str] = Field(alias="countryCode", default=None)
    country_name: Optional[str] = Field(alias="countryName", default=None)
    area_code: Optional[str] = Field(alias="areaCode", default=None)
    area_name: Optional[str] = Field(alias="areaName", default=None)
    age_code: Optional[str] = Field(alias="ageCode", default=None)
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor", default=None)
    category_code: Optional[str] = Field(alias="categoryCode", default=None)
    category_name: Optional[str] = Field(alias="categoryName", default=None)
    category_order: Optional[int] = Field(alias="categoryOrder", default=None)
    sub_category_code: Optional[str] = Field(alias="subCategoryCode", default=None)
    sub_category_name: Optional[str] = Field(alias="subCategoryName", default=None)
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder", default=None)
    event_id_wa: Optional[int] = Field(alias="eventId_WA", default=None)
    class_code: Optional[str] = Field(alias="classCode", default=None)
    class_name: Optional[str] = Field(alias="className", default=None)
    class_order: Optional[int] = Field(alias="classOrder", default=None)
    is_published: Optional[bool] = Field(alias="isPublished", default=None)
    has_comp_doc_results: Optional[bool] = Field(
        alias="hasCompDocResults", default=None
    )
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug", default=None)
    start_date_year: Optional[int] = Field(alias="startDateYear", default=None)
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug", default=None)
    category_name_url_slug: Optional[str] = Field(
        alias="categoryNameUrlSlug", default=None
    )
    sub_category_name_url_slug: Optional[str] = Field(
        alias="subCategoryNameUrlSlug", default=None
    )
    discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="disciplineCodes", default=None
    )


class FlashInterviewInput(BaseModel):
    id: Optional[int] = None
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    phase_date: Optional[Any] = Field(alias="phaseDate", default=None)
    phase_name: Optional[str] = Field(alias="phaseName", default=None)
    unit_id: Optional[int] = Field(alias="unitId", default=None)
    unit_code: Optional[int] = Field(alias="unitCode", default=None)
    unit_type_name: Optional[str] = Field(alias="unitTypeName", default=None)
    unit_name: Optional[str] = Field(alias="unitName", default=None)
    title: Optional[str] = None
    body: Optional[str] = None
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_team_name: Optional[str] = Field(
        alias="competitorTeamName", default=None
    )
    competitor_forename: Optional[str] = Field(alias="competitorForename", default=None)
    competitor_surname: Optional[str] = Field(alias="competitorSurname", default=None)
    competitor_country_code: Optional[str] = Field(
        alias="competitorCountryCode", default=None
    )
    competitor_sex: Optional[str] = Field(alias="competitorSex", default=None)
    competitor_type: Optional[str] = Field(alias="competitorType", default=None)
    updated_on: Optional[Any] = Field(alias="updatedOn", default=None)
    event_id: Optional[int] = Field(alias="eventId", default=None)
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    discipline_name: Optional[str] = Field(alias="disciplineName", default=None)
    discipline_sex_name: Optional[str] = Field(alias="disciplineSexName", default=None)
    flash_interview_order: Optional[int] = Field(
        alias="flashInterviewOrder", default=None
    )
    flash_interview_date: Optional[Any] = Field(
        alias="flashInterviewDate", default=None
    )
    flash_interview_has_time: Optional[bool] = Field(
        alias="flashInterviewHasTime", default=None
    )
    event_store_id: Optional[str] = Field(alias="eventStoreId", default=None)


class LiveCombinedSummaryDetailInput(BaseModel):
    id: Optional[str] = None
    competition_id: Optional[int] = Field(alias="competitionId", default=None)
    phase_id: int = Field(alias="phaseId")
    overall_rank: Optional[int] = Field(alias="overallRank", default=None)
    bib: Optional[str] = None
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_first_name: Optional[str] = Field(
        alias="competitorFirstName", default=None
    )
    competitor_last_name: Optional[str] = Field(
        alias="competitorLastName", default=None
    )
    competitor_country_code: Optional[str] = Field(
        alias="competitorCountryCode", default=None
    )
    competitor_birth_date: Optional[str] = Field(
        alias="competitorBirthDate", default=None
    )
    result_mark: Optional[str] = Field(alias="resultMark", default=None)
    record: Optional[str] = None
    details_disc_order: Optional[int] = Field(alias="detailsDiscOrder", default=None)
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    discipline_mark: Optional[str] = Field(alias="disciplineMark", default=None)
    detail_wind: Optional[str] = Field(alias="detailWind", default=None)
    overall_points: Optional[int] = Field(alias="overallPoints", default=None)
    overall_order: Optional[int] = Field(alias="overallOrder", default=None)
    detail_combined_rank: Optional[str] = Field(
        alias="detailCombinedRank", default=None
    )
    discipline_rank: Optional[str] = Field(alias="disciplineRank", default=None)
    discipline_points: Optional[str] = Field(alias="disciplinePoints", default=None)
    update_on: Optional[str] = Field(alias="updateOn", default=None)
    combined_type: Optional[str] = Field(alias="combinedType", default=None)


class LivePhaseSummaryInput(BaseModel):
    id: str
    phase_summary_id: Optional[int] = Field(alias="phaseSummaryId", default=None)
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    unit_id: Optional[int] = Field(alias="unitId", default=None)
    unit_name: Optional[str] = Field(alias="unitName", default=None)
    unit_type: Optional[str] = Field(alias="unitType", default=None)
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_team_name: Optional[str] = Field(
        alias="competitorTeamName", default=None
    )
    competitor_forename: Optional[str] = Field(alias="competitorForename", default=None)
    competitor_surname: Optional[str] = Field(alias="competitorSurname", default=None)
    competitor_country_name: Optional[str] = Field(
        alias="competitorCountryName", default=None
    )
    competitor_country_code: Optional[str] = Field(
        alias="competitorCountryCode", default=None
    )
    competitor_sex: Optional[str] = Field(alias="competitorSex", default=None)
    competitor_type: Optional[str] = Field(alias="competitorType", default=None)
    bib: Optional[str] = None
    rank: Optional[str] = None
    mark: Optional[str] = None
    wind: Optional[str] = None
    result_wind: Optional[str] = Field(alias="resultWind", default=None)
    record: Optional[str] = None
    qualified: Optional[str] = None
    combined_points: Optional[str] = Field(alias="combinedPoints", default=None)
    updated_on: Optional[str] = Field(alias="updatedOn", default=None)
    result_rank: Optional[str] = Field(alias="resultRank", default=None)
    phase_summary_order: Optional[int] = Field(alias="phaseSummaryOrder", default=None)
    provisional_qualifier: Optional[bool] = Field(
        alias="provisionalQualifier", default=None
    )
    competition_id: Optional[int] = Field(alias="competitionId", default=None)
    reaction_time: Optional[str] = Field(alias="reactionTime", default=None)
    phase_summary_milliseconds: Optional[str] = Field(
        alias="phaseSummaryMilliseconds", default=None
    )


class LivePhaseSummaryQuery(BaseModel):
    phase_id: Optional[int] = Field(alias="phaseId", default=None)


class LiveResultInput(BaseModel):
    type: Optional[str] = None
    id: str
    phase_id: int = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId", default=None)
    unit_name: Optional[str] = Field(alias="unitName", default=None)
    unit_type: Optional[str] = Field(alias="unitType", default=None)
    intermediate_type: Optional[str] = Field(alias="intermediateType", default=None)
    intermediate_id: Optional[int] = Field(alias="intermediateId", default=None)
    split_name: Optional[str] = Field(alias="splitName", default=None)
    intermediate_id_type: Optional[str] = Field(
        alias="intermediateIdType", default=None
    )
    intermediate_result_order: Optional[int] = Field(
        alias="intermediateResultOrder", default=None
    )
    intermediate_order: Optional[int] = Field(alias="intermediateOrder", default=None)
    standing_points: Optional[str] = Field(alias="standingPoints", default=None)
    gap: Optional[str] = None
    result_id: Optional[int] = Field(alias="resultId", default=None)
    no_start: Optional[bool] = Field(alias="noStart", default=None)
    lane: Optional[str] = None
    season_best_mark: Optional[str] = Field(alias="seasonBestMark", default=None)
    personal_best_mark: Optional[str] = Field(alias="personalBestMark", default=None)
    phase_summary_order: Optional[int] = Field(alias="phaseSummaryOrder", default=None)
    result_ranks: Optional[int] = Field(alias="resultRanks", default=None)
    summary_yank: Optional[int] = Field(alias="summaryYank", default=None)
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_forename: Optional[str] = Field(alias="competitorForename", default=None)
    competitor_surname: Optional[str] = Field(alias="competitorSurname", default=None)
    competitor_team_name: Optional[str] = Field(
        alias="competitorTeamName", default=None
    )
    competitor_country_name: Optional[str] = Field(
        alias="competitorCountryName", default=None
    )
    competitor_country_code: Optional[str] = Field(
        alias="competitorCountryCode", default=None
    )
    competitor_sex: Optional[str] = Field(alias="competitorSex", default=None)
    competitor_type: Optional[str] = Field(alias="competitorType", default=None)
    bib: Optional[str] = None
    rank: Optional[str] = None
    mark: Optional[str] = None
    combined_points: Optional[str] = Field(alias="combinedPoints", default=None)
    reaction_time: Optional[str] = Field(alias="reactionTime", default=None)
    record: Optional[str] = None
    result_order: Optional[int] = Field(alias="resultOrder", default=None)
    start_order: Optional[int] = Field(alias="startOrder", default=None)
    qualified: Optional[str] = None
    next: Optional[bool] = None
    last: Optional[bool] = None
    updated_on: Optional[str] = Field(alias="updatedOn", default=None)
    wind: Optional[str] = None
    team_name: Optional[str] = Field(alias="teamName", default=None)
    team_members: Optional[List[Optional["LiveResultTeamMemberInput"]]] = Field(
        alias="teamMembers", default=None
    )
    competition_id: Optional[int] = Field(alias="competitionId", default=None)
    result_milliseconds: Optional[str] = Field(alias="resultMilliseconds", default=None)
    world_ranking: Optional[str] = Field(alias="worldRanking", default=None)


class LiveResultTeamMemberInput(BaseModel):
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    unit_id: Optional[int] = Field(alias="unitId", default=None)
    unit_name: Optional[str] = Field(alias="unitName", default=None)
    live_result_id: Optional[int] = Field(alias="liveResultId", default=None)
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_forename: Optional[str] = Field(alias="competitorForename", default=None)
    competitor_surname: Optional[str] = Field(alias="competitorSurname", default=None)
    competitor_country_name: Optional[str] = Field(
        alias="competitorCountryName", default=None
    )
    competitor_country_code: Optional[str] = Field(
        alias="competitorCountryCode", default=None
    )


class MedalDetailInput(BaseModel):
    id: Optional[int] = None
    medal_table_id: Optional[int] = Field(alias="medalTableId", default=None)
    type_id: Optional[int] = Field(alias="typeId", default=None)
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    discipline_name: Optional[str] = Field(alias="disciplineName", default=None)
    sex_code: Optional[str] = Field(alias="sexCode", default=None)
    result_id: Optional[int] = Field(alias="resultId", default=None)
    result_mark: Optional[str] = Field(alias="resultMark", default=None)
    medal_date: Optional[str] = Field(alias="medalDate", default=None)
    details_order: Optional[int] = Field(alias="detailsOrder", default=None)
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_first_name: Optional[str] = Field(
        alias="competitorFirstName", default=None
    )
    competitor_last_name: Optional[str] = Field(
        alias="competitorLastName", default=None
    )
    event_id: Optional[int] = Field(alias="eventId", default=None)
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    updated_on: Optional[str] = Field(alias="updatedOn", default=None)


class MedalInput(BaseModel):
    id: int
    event_id: int = Field(alias="eventId")
    country_code: Optional[str] = Field(alias="countryCode", default=None)
    country_name: Optional[str] = Field(alias="countryName", default=None)
    event_medal_table_order: Optional[int] = Field(
        alias="eventMedalTableOrder", default=None
    )
    event_sub_category_code: Optional[str] = Field(
        alias="eventSubCategoryCode", default=None
    )
    medal_rank: Optional[int] = Field(alias="medalRank", default=None)
    bronze: Optional[int] = None
    silver: Optional[int] = None
    gold: Optional[int] = None
    total: Optional[int] = None
    updated_on: Optional[str] = Field(alias="updatedOn", default=None)


class MedalMutationInput(BaseModel):
    event_id: int = Field(alias="eventId")
    payload: List["MedalInput"]


class PhaseInput(BaseModel):
    id: Optional[int] = None
    phase_code: Optional[str] = Field(alias="phaseCode", default=None)
    discipline_name: Optional[str] = Field(alias="disciplineName", default=None)
    discipline_order: Optional[int] = Field(alias="disciplineOrder", default=None)
    type_name: Optional[str] = Field(alias="typeName", default=None)
    type_code: Optional[str] = Field(alias="typeCode", default=None)
    type_order: Optional[int] = Field(alias="typeOrder", default=None)
    is_combined: Optional[bool] = Field(alias="isCombined", default=None)
    is_indoor: Optional[bool] = Field(alias="isIndoor", default=None)
    is_reaction: Optional[bool] = Field(alias="isReaction", default=None)
    is_outdoor: Optional[bool] = Field(alias="isOutdoor", default=None)
    is_wind: Optional[bool] = Field(alias="isWind", default=None)
    is_valid_iaaf: Optional[bool] = Field(alias="isValidIAAF", default=None)
    is_relay: Optional[bool] = Field(alias="isRelay", default=None)
    is_walk: Optional[bool] = Field(alias="isWalk", default=None)
    is_road: Optional[bool] = Field(alias="isRoad", default=None)
    is_field: Optional[bool] = Field(alias="isField", default=None)
    is_track: Optional[bool] = Field(alias="isTrack", default=None)
    is_in_lane: Optional[bool] = Field(alias="isInLane", default=None)
    has_reaction_times: Optional[bool] = Field(alias="hasReactionTimes", default=None)
    has_wind_measurement: Optional[bool] = Field(
        alias="hasWindMeasurement", default=None
    )
    inout_code: Optional[bool] = Field(alias="inoutCode", default=None)
    has_team_standing: Optional[bool] = Field(alias="hasTeamStanding", default=None)
    disc_code_group: Optional[str] = Field(alias="discCodeGroup", default=None)
    phase_name: Optional[str] = Field(alias="phaseName", default=None)
    event_id: Optional[int] = Field(alias="eventId", default=None)
    event_id_wa: Optional[int] = Field(alias="eventId_WA", default=None)
    phase_date_and_time: Optional[str] = Field(alias="phaseDateAndTime", default=None)
    sex_code: Optional[str] = Field(alias="sexCode", default=None)
    sex_name: Optional[str] = Field(alias="sexName", default=None)
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    is_startlist_published: Optional[bool] = Field(
        alias="isStartlistPublished", default=None
    )
    is_result_published: Optional[bool] = Field(alias="isResultPublished", default=None)
    is_phase_summary_published: Optional[bool] = Field(
        alias="isPhaseSummaryPublished", default=None
    )
    is_team_standing_published: Optional[bool] = Field(
        alias="isTeamStandingPublished", default=None
    )
    combined_discipline_order: Optional[str] = Field(
        alias="combinedDisciplineOrder", default=None
    )
    phase_order: Optional[int] = Field(alias="phaseOrder", default=None)
    phase_session_order: Optional[int] = Field(alias="phaseSessionOrder", default=None)
    phase_session_name: Optional[str] = Field(alias="phaseSessionName", default=None)
    primary_phase_order: Optional[int] = Field(alias="primaryPhaseOrder", default=None)
    status: Optional[int] = None
    has_time: Optional[int] = Field(alias="hasTime", default=None)
    updated_on: Optional[str] = Field(alias="updatedOn", default=None)
    units: List["UnitInput"]


class PhaseQueryInput(BaseModel):
    competition_id: int = Field(alias="competitionId")
    sex_code: Optional[str] = Field(alias="sexCode", default=None)
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)


class PlacingTableDetailInput(BaseModel):
    id: int
    placing_table_id: int = Field(alias="placingTableId")
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    discipline_name: Optional[str] = Field(alias="disciplineName", default=None)
    competitor_first_name: Optional[str] = Field(
        alias="competitorFirstName", default=None
    )
    competitor_last_name: Optional[str] = Field(
        alias="competitorLastName", default=None
    )
    sex_code: Optional[str] = Field(alias="sexCode", default=None)
    placing_date: Optional[Any] = Field(alias="placingDate", default=None)
    details_order: Optional[int] = Field(alias="detailsOrder", default=None)
    event_id: Optional[int] = Field(alias="eventId", default=None)
    type_id: Optional[int] = Field(alias="typeId", default=None)
    type_name: Optional[str] = Field(alias="typeName", default=None)
    type_abbreviation: Optional[str] = Field(alias="typeAbbreviation", default=None)
    result_mark: Optional[str] = Field(alias="resultMark", default=None)
    placing_points: Optional[str] = Field(alias="placingPoints", default=None)
    result_id: Optional[int] = Field(alias="resultId", default=None)
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    country_code: Optional[str] = Field(alias="countryCode", default=None)
    updated_on: Optional[Any] = Field(alias="updatedOn", default=None)


class PlacingTableInput(BaseModel):
    id: int
    event_id: int = Field(alias="eventId")
    rank: Optional[int] = None
    country_name: Optional[str] = Field(alias="countryName", default=None)
    country_code: Optional[str] = Field(alias="countryCode", default=None)
    gold: Optional[int] = None
    silver: Optional[int] = None
    bronze: Optional[int] = None
    forth: Optional[int] = None
    fifth: Optional[int] = None
    sixth: Optional[int] = None
    seventh: Optional[int] = None
    eighth: Optional[int] = None
    points: Optional[int] = None
    table_order: Optional[int] = Field(alias="tableOrder", default=None)
    sub_category_code: Optional[str] = Field(alias="subCategoryCode", default=None)
    updated_on: Optional[Any] = Field(alias="updatedOn", default=None)


class PreviousMedalQuery(BaseModel):
    event_id: Optional[int] = Field(alias="eventId", default=None)
    event_id_wa: Optional[int] = Field(alias="eventId_WA", default=None)
    event_end_date: Optional[str] = Field(alias="eventEndDate", default=None)
    sub_category_code: Optional[str] = Field(alias="subCategoryCode", default=None)
    gender: Optional[str] = None
    discipline_code: Optional[str] = Field(alias="disciplineCode", default=None)
    indoor_out_door: Optional[str] = Field(alias="indoorOutDoor", default=None)


class TeamQuery(BaseModel):
    team_id: Optional[int] = Field(alias="teamId", default=None)
    team_sex: Optional[str] = Field(alias="teamSex", default=None)
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor", default=None)


class TeamScoringInput(BaseModel):
    id: str
    team_id: Optional[int] = Field(alias="teamId", default=None)
    team_id_wa: Optional[int] = Field(alias="teamId_WA", default=None)
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    unit_id: Optional[int] = Field(alias="unitId", default=None)
    scoring_team_id: Optional[int] = Field(alias="scoringTeamId", default=None)
    result_id: Optional[int] = Field(alias="resultId", default=None)
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId", default=None)
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_id_wa: Optional[int] = Field(alias="competitorId_WA", default=None)
    team_name: Optional[str] = Field(alias="teamName", default=None)
    team_country_code: Optional[str] = Field(alias="teamCountryCode", default=None)
    updated_on: Optional[Any] = Field(alias="updatedOn", default=None)
    scoring_team_order: Optional[int] = Field(alias="scoringTeamOrder", default=None)
    scoring_team_detail_order: Optional[int] = Field(
        alias="scoringTeamDetailOrder", default=None
    )
    bib: Optional[str] = None
    event_store_id: Optional[str] = Field(alias="eventStoreId", default=None)
    chunk_order: Optional[int] = Field(alias="chunkOrder", default=None)
    chunk_id: Optional[str] = Field(alias="chunkId", default=None)


class TeamStandingsInput(BaseModel):
    id: Optional[int] = None
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    unit_id: Optional[int] = Field(alias="unitId", default=None)
    competition_intermediate_id: Optional[int] = Field(
        alias="competitionIntermediateId", default=None
    )
    competition_intermediate_name: Optional[str] = Field(
        alias="competitionIntermediateName", default=None
    )
    rank: Optional[int] = None
    team_id: Optional[int] = Field(alias="teamId", default=None)
    team_id_wa: Optional[int] = Field(alias="teamId_WA", default=None)
    team_name: Optional[str] = Field(alias="teamName", default=None)
    team_country_code: Optional[str] = Field(alias="teamCountryCode", default=None)
    standing_mark: Optional[str] = Field(alias="standingMark", default=None)
    live_current: Optional[bool] = Field(alias="liveCurrent", default=None)
    updated_on: Optional[Any] = Field(alias="updatedOn", default=None)
    team_standing_id: Optional[int] = Field(alias="teamStandingId", default=None)
    competition_intermediate_order: Optional[int] = Field(
        alias="competitionIntermediateOrder", default=None
    )
    detail_rank: Optional[int] = Field(alias="detailRank", default=None)
    standing_detail_bib: Optional[str] = Field(alias="standingDetailBib", default=None)
    competitor_id: Optional[int] = Field(alias="competitorId", default=None)
    competitor_id_wa: Optional[int] = Field(alias="competitorId_WA", default=None)
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId", default=None)
    standing_detail_score: Optional[str] = Field(
        alias="standingDetailScore", default=None
    )
    standing_detail_scoring: Optional[str] = Field(
        alias="standingDetailScoring", default=None
    )
    team_standing_order: Optional[int] = Field(alias="teamStandingOrder", default=None)
    team_standing_detail_order: Optional[int] = Field(
        alias="teamStandingDetailOrder", default=None
    )
    chunk_order: Optional[int] = Field(alias="chunkOrder", default=None)
    chunk_id: Optional[str] = Field(alias="chunkId", default=None)


class UnitInput(BaseModel):
    id: Optional[int] = None
    phase_id: Optional[int] = Field(alias="phaseId", default=None)
    unit_name: Optional[str] = Field(alias="unitName", default=None)
    unit_type: Optional[str] = Field(alias="unitType", default=None)
    unit_order: Optional[int] = Field(alias="unitOrder", default=None)
    is_startlist_published: Optional[bool] = Field(
        alias="isStartlistPublished", default=None
    )
    is_result_published: Optional[bool] = Field(alias="isResultPublished", default=None)
    is_phase_summary_published: Optional[bool] = Field(
        alias="isPhaseSummaryPublished", default=None
    )
    is_team_standing_published: Optional[bool] = Field(
        alias="isTeamStandingPublished", default=None
    )
    combined_discipline_order: Optional[str] = Field(
        alias="combinedDisciplineOrder", default=None
    )
    status: Optional[str] = None
    qualification_rule_code: Optional[str] = Field(
        alias="qualificationRuleCode", default=None
    )
    updated_on: Optional[str] = Field(alias="updatedOn", default=None)
    start_date: Optional[str] = Field(alias="startDate", default=None)
    start_time: Optional[str] = Field(alias="startTime", default=None)
    start_date_time: Optional[str] = Field(alias="startDateTime", default=None)
    wind: Optional[str] = None


LiveResultInput.model_rebuild()
MedalMutationInput.model_rebuild()
PhaseInput.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventPhases(BaseModel):
    get_event_phases: Optional[List[Optional["GetEventPhasesGetEventPhases"]]] = Field(
        alias="getEventPhases"
    )


class GetEventPhasesGetEventPhases(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    phase_code: Optional[str] = Field(alias="phaseCode")
    phase_name: Optional[str] = Field(alias="phaseName")
    event_id: Optional[int] = Field(alias="eventID")
    phase_date_and_time: Optional[Any] = Field(alias="phaseDateAndTime")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    discipline: Optional["GetEventPhasesGetEventPhasesDiscipline"]
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[int] = Field(alias="combinedDisciplineOrder")
    phase_order: Optional[int] = Field(alias="phaseOrder")
    phase_session_name: Optional[str] = Field(alias="phaseSessionName")
    phase_session_order: Optional[int] = Field(alias="phaseSessionOrder")
    status: Optional[int]
    has_time: Optional[bool] = Field(alias="hasTime")
    event_id_wa: Optional[int] = Field(alias="eventId_WA")
    primary_phase_order: Optional[int] = Field(alias="primaryPhaseOrder")
    is_points_published: Optional[bool] = Field(alias="isPointsPublished")
    phase_name_url_slug: Optional[str] = Field(alias="phaseNameUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type_name: Optional[str] = Field(alias="unitTypeName")


class GetEventPhasesGetEventPhasesDiscipline(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str] = Field(alias="_id")
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_iaaf: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


GetEventPhases.model_rebuild()
GetEventPhasesGetEventPhases.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRecordsDetailByDiscipline(BaseModel):
    get_records_detail_by_discipline: Optional[
        List[Optional["GetRecordsDetailByDisciplineGetRecordsDetailByDiscipline"]]
    ] = Field(alias="getRecordsDetailByDiscipline")


class GetRecordsDetailByDisciplineGetRecordsDetailByDiscipline(BaseModel):
    age_category: Optional[str] = Field(alias="ageCategory")
    items: Optional[
        List[Optional["GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItems"]]
    ]


class GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItems(BaseModel):
    progression_list_id: Optional[int] = Field(alias="progressionListId")
    category: Optional[str]
    category_id: Optional[int] = Field(alias="categoryId")
    performance: Optional[str]
    equal: Optional[bool]
    pending: Optional[bool]
    set_indoor: Optional[bool] = Field(alias="setIndoor")
    women_only: Optional[bool] = Field(alias="womenOnly")
    mixed: Optional[bool]
    yard: Optional[bool]
    wind: Optional[str]
    competitor: Optional[
        "GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitor"
    ]
    country: Optional[str]
    venue: Optional[str]
    date: Optional[str]


class GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitor(
    BaseModel
):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    name: Optional[str]
    country: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    has_profile: Optional[bool] = Field(alias="hasProfile")
    team_members: Optional[
        List[
            Optional[
                "GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitorTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitorTeamMembers(
    BaseModel
):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    name: Optional[str]
    country: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    has_profile: Optional[bool] = Field(alias="hasProfile")


GetRecordsDetailByDiscipline.model_rebuild()
GetRecordsDetailByDisciplineGetRecordsDetailByDiscipline.model_rebuild()
GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItems.model_rebuild()
GetRecordsDetailByDisciplineGetRecordsDetailByDisciplineItemsCompetitor.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetTopPanel(BaseModel):
    get_top_panel: Optional[List[Optional["GetTopPanelGetTopPanel"]]] = Field(
        alias="getTopPanel"
    )


class GetTopPanelGetTopPanel(BaseModel):
    title: Optional[str]
    subtitle: Optional[str]
    description: Optional[str]
    button_label: Optional[str] = Field(alias="buttonLabel")
    button_link: Optional[str] = Field(alias="buttonLink")
    logo: Optional[str]


GetTopPanel.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRecordsDetailByCategory(BaseModel):
    get_records_detail_by_category: Optional[
        List[Optional["GetRecordsDetailByCategoryGetRecordsDetailByCategory"]]
    ] = Field(alias="getRecordsDetailByCategory")


class GetRecordsDetailByCategoryGetRecordsDetailByCategory(BaseModel):
    gender: Optional[str]
    results: Optional[
        List[Optional["GetRecordsDetailByCategoryGetRecordsDetailByCategoryResults"]]
    ]


class GetRecordsDetailByCategoryGetRecordsDetailByCategoryResults(BaseModel):
    progression_list_id: Optional[int] = Field(alias="progressionListId")
    discipline: Optional[str]
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    performance: Optional[str]
    pending: Optional[bool]
    set_indoor: Optional[bool] = Field(alias="setIndoor")
    equal: Optional[bool]
    women_only: Optional[bool] = Field(alias="womenOnly")
    mixed: Optional[bool]
    yard: Optional[bool]
    wind: Optional[str]
    competitor: Optional[
        "GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitor"
    ]
    venue: Optional[str]
    country: Optional[str]
    date: Optional[str]


class GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitor(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    name: Optional[str]
    country: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    has_profile: Optional[bool] = Field(alias="hasProfile")
    team_members: Optional[
        List[
            Optional[
                "GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitorTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitorTeamMembers(
    BaseModel
):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    name: Optional[str]
    country: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    has_profile: Optional[bool] = Field(alias="hasProfile")


GetRecordsDetailByCategory.model_rebuild()
GetRecordsDetailByCategoryGetRecordsDetailByCategory.model_rebuild()
GetRecordsDetailByCategoryGetRecordsDetailByCategoryResults.model_rebuild()
GetRecordsDetailByCategoryGetRecordsDetailByCategoryResultsCompetitor.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetUserCountry(BaseModel):
    get_user_country: Optional["GetUserCountryGetUserCountry"] = Field(
        alias="getUserCountry"
    )


class GetUserCountryGetUserCountry(BaseModel):
    ip: Optional[str]
    country: Optional[str]


GetUserCountry.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCISSingleCompetitor(BaseModel):
    get_cis_single_competitor: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitor"
    ] = Field(alias="getCISSingleCompetitor")


class GetCISSingleCompetitorGetCisSingleCompetitor(BaseModel):
    basic_data: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorBasicData"
    ] = Field(alias="basicData")
    personal_bests: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorPersonalBests"
    ] = Field(alias="personalBests")
    seasons_bests: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBests"
    ] = Field(alias="seasonsBests")
    progression_of_seasons_bests: Optional[
        List[
            Optional[
                "GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBests"
            ]
        ]
    ] = Field(alias="progressionOfSeasonsBests")
    world_rankings: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorWorldRankings"
    ] = Field(alias="worldRankings")
    honours: Optional[
        List[Optional["GetCISSingleCompetitorGetCisSingleCompetitorHonours"]]
    ]
    results_by_year: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYear"
    ] = Field(alias="resultsByYear")
    results_by_date: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorResultsByDate"
    ] = Field(alias="resultsByDate")
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    athlete_representative: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorAthleteRepresentative"
    ] = Field(alias="athleteRepresentative")
    road_race_label_status: Optional[
        List[
            Optional["GetCISSingleCompetitorGetCisSingleCompetitorRoadRaceLabelStatus"]
        ]
    ] = Field(alias="roadRaceLabelStatus")


class GetCISSingleCompetitorGetCisSingleCompetitorBasicData(BaseModel):
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    sex_name: Optional[str] = Field(alias="sexName")
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    butlers_bio: Optional[str] = Field(alias="butlersBio")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    biography: Optional[str]
    twitter_link: Optional[str] = Field(alias="twitterLink")
    instagram_link: Optional[str] = Field(alias="instagramLink")
    facebook_link: Optional[str] = Field(alias="facebookLink")
    iaaf_id: Optional[int] = Field(alias="iaafId")
    aa_id: Optional[int] = Field(alias="aaId")


class GetCISSingleCompetitorGetCisSingleCompetitorPersonalBests(BaseModel):
    with_wind: Optional[bool] = Field(alias="withWind")
    with_records: Optional[bool] = Field(alias="withRecords")
    results: Optional[
        List[
            Optional["GetCISSingleCompetitorGetCisSingleCompetitorPersonalBestsResults"]
        ]
    ]


class GetCISSingleCompetitorGetCisSingleCompetitorPersonalBestsResults(BaseModel):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    link_to_list: Optional[bool] = Field(alias="linkToList")
    mark: Optional[str]
    combined_performances: Optional[str] = Field(alias="combinedPerformances")
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    venue: Optional[str]
    date: Optional[str]
    list_position: Optional[str] = Field(alias="listPosition")
    result_score: Optional[int] = Field(alias="resultScore")


class GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBests(BaseModel):
    parameters: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsParameters"
    ]
    active_seasons: Optional[List[Optional[str]]] = Field(alias="activeSeasons")
    with_wind: Optional[bool] = Field(alias="withWind")
    with_records: Optional[bool] = Field(alias="withRecords")
    results: Optional[
        List[
            Optional["GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsResults"]
        ]
    ]


class GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsParameters(BaseModel):
    seasons_bests_season: Optional[int] = Field(alias="seasonsBestsSeason")


class GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBestsResults(BaseModel):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    link_to_list: Optional[bool] = Field(alias="linkToList")
    mark: Optional[str]
    combined_performances: Optional[str] = Field(alias="combinedPerformances")
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    venue: Optional[str]
    date: Optional[str]
    list_position: Optional[str] = Field(alias="listPosition")
    result_score: Optional[int] = Field(alias="resultScore")


class GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBests(BaseModel):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    with_wind: Optional[bool] = Field(alias="withWind")
    main_event: Optional[bool] = Field(alias="mainEvent")
    results: Optional[
        List[
            Optional[
                "GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBestsResults"
            ]
        ]
    ]


class GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBestsResults(
    BaseModel
):
    season: Optional[str]
    numeric_result: Optional[float] = Field(alias="numericResult")
    mark: Optional[str]
    wind: Optional[str]
    venue: Optional[str]
    date: Optional[str]
    list_position: Optional[int] = Field(alias="listPosition")
    result_score: Optional[int] = Field(alias="resultScore")


class GetCISSingleCompetitorGetCisSingleCompetitorWorldRankings(BaseModel):
    parameters: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsParameters"
    ]
    current: Optional[
        List[
            Optional["GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsCurrent"]
        ]
    ]
    best: Optional[
        List[Optional["GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsBest"]]
    ]


class GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsParameters(BaseModel):
    world_rankings_progression_year: Optional[int] = Field(
        alias="worldRankingsProgressionYear"
    )


class GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsCurrent(BaseModel):
    ranking_calculation_id: Optional[str] = Field(alias="rankingCalculationId")
    event_group: Optional[str] = Field(alias="eventGroup")
    male: Optional[bool]
    url_slug: Optional[str] = Field(alias="urlSlug")
    place: Optional[int]
    ranking_score: Optional[int] = Field(alias="rankingScore")


class GetCISSingleCompetitorGetCisSingleCompetitorWorldRankingsBest(BaseModel):
    event_group: Optional[str] = Field(alias="eventGroup")
    event_group_id: Optional[int] = Field(alias="eventGroupId")
    url_slug: Optional[str] = Field(alias="urlSlug")
    place: Optional[str]
    weeks: Optional[int]


class GetCISSingleCompetitorGetCisSingleCompetitorHonours(BaseModel):
    category_name: Optional[str] = Field(alias="categoryName")
    with_wind: Optional[bool] = Field(alias="withWind")
    with_drop: Optional[bool] = Field(alias="withDrop")
    results: Optional[
        List[Optional["GetCISSingleCompetitorGetCisSingleCompetitorHonoursResults"]]
    ]


class GetCISSingleCompetitorGetCisSingleCompetitorHonoursResults(BaseModel):
    place: Optional[str]
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    date: Optional[str]


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByYear(BaseModel):
    parameters: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearParameters"
    ]
    active_years: Optional[List[Optional[str]]] = Field(alias="activeYears")
    results_by_event: Optional[
        List[
            Optional[
                "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEvent"
            ]
        ]
    ] = Field(alias="resultsByEvent")


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearParameters(BaseModel):
    results_by_year: Optional[int] = Field(alias="resultsByYear")
    results_by_year_order_by: Optional[str] = Field(alias="resultsByYearOrderBy")


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEvent(
    BaseModel
):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    with_wind: Optional[bool] = Field(alias="withWind")
    with_remark: Optional[bool] = Field(alias="withRemark")
    results: Optional[
        List[
            Optional[
                "GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEventResults"
            ]
        ]
    ]


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEventResults(
    BaseModel
):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByDate(BaseModel):
    parameters: Optional[
        "GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateParameters"
    ]
    active_years: Optional[List[Optional[str]]] = Field(alias="activeYears")
    with_remark: Optional[bool] = Field(alias="withRemark")
    results_by_date: Optional[
        List[
            Optional[
                "GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateResultsByDate"
            ]
        ]
    ] = Field(alias="resultsByDate")


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateParameters(BaseModel):
    results_by_year: Optional[int] = Field(alias="resultsByYear")
    results_by_year_order_by: Optional[str] = Field(alias="resultsByYearOrderBy")


class GetCISSingleCompetitorGetCisSingleCompetitorResultsByDateResultsByDate(BaseModel):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


class GetCISSingleCompetitorGetCisSingleCompetitorAthleteRepresentative(BaseModel):
    name: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    email: Optional[str]
    telephone: Optional[str]
    mobile: Optional[str]
    rep_email: Optional[str] = Field(alias="repEmail")
    website: Optional[str]


class GetCISSingleCompetitorGetCisSingleCompetitorRoadRaceLabelStatus(BaseModel):
    year: Optional[str]
    label_status: Optional[str] = Field(alias="labelStatus")


GetCISSingleCompetitor.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitor.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorPersonalBests.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorSeasonsBests.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorProgressionOfSeasonsBests.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorWorldRankings.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorHonours.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorResultsByYear.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorResultsByYearResultsByEvent.model_rebuild()
GetCISSingleCompetitorGetCisSingleCompetitorResultsByDate.model_rebuild()
